@@ -1,6 +1,6 @@
 package Net::OpenSSH::Compat;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use strict;
 use warnings;
@@ -41,7 +41,28 @@ CPAN.
 Currently, there are an only adapter available for
 L<Net::SSH2>. Adapters for L<Net::SSH> and L<Net::SSH::Perl> are
 planned... maybe also for L<Net::SCP> and L<Net::SCP::Expect> if
-somebody request then.
+somebody request them.
+
+=head1 BUGS AND SUPPORT
+
+B<This is a work in progress.>
+
+If you find any bug fill a report at the CPAN RT bugtracker
+(L<https://rt.cpan.org/Ticket/Create.html?Queue=Net-OpenSSH-Compat>)
+or just send me an e-mail with the details.
+
+=head2 Git repository
+
+The source code repository is at
+L<https://github.com/salva/p5-Net-OpenSSH-Compat>.
+
+=head2 My wishlist
+
+If you like this module and you're feeling generous, take a look at my
+Amazon Wish List: L<http://amzn.com/w/1WU1P6IR5QZ42>
+
+Also consider contributing to the OpenSSH project this module builds
+upon: L<http://www.openssh.org/donations.html>.
 
 =head1 SEE ALSO
 
